@@ -1,3 +1,4 @@
+from ast import Or
 from pathlib import Path
 from typing import (
     TYPE_CHECKING,
@@ -333,7 +334,7 @@ def _handle_complex_polygon(annotation: dt.Annotation, data: Dict[str, Any]) ->
 
 def _import_annotations(
     client: "Client",
-    id: int,
+    id: Union[str, int],
     remote_classes: Dict[str, Any],
     attributes: Dict[str, Any],
     annotations: List[dt.Annotation],
@@ -358,13 +359,23 @@ def _import_annotations(
             data = _handle_complex_polygon(annotation, data)
             data = _handle_subs(annotation, data, annotation_class_id, attributes)
 
-        serialized_annotations.append({"annotation_class_id": annotation_class_id, "data": data})
+        # Fetch the default slot name if no available in the import source
+        if not annotation.slot_names and dataset.version > 1:
+            items = dataset.fetch_remote_files(filters={"dataset_item_ids": [str(id)]})
+            if items:
+                first_item = next(items)
+                annotation.slot_names.extend([first_item.slots[0]["slot_name"]])
+
+        serialized_annotations.append(
+            {
+                "annotation_class_id": annotation_class_id,
+                "data": data,
+                "context_keys": {"slot_names": annotation.slot_names},
+            }
+        )
 
     payload: Dict[str, Any] = {"annotations": serialized_annotations}
     if append:
         payload["overwrite"] = "false"
 
-    try:
-        client.import_annotation(id, payload=payload)
-    except:
-        print(f"warning, failed to upload annotation to item {id}. Annotations: {payload}")
+    dataset.import_annotation(id, payload=payload)
